============================
Widgets
============================
PyDM comes with a set of widgets useful for operating a control system.


Display Widgets
---------------
.. toctree::
   :maxdepth: 1

   byte.rst
   multistate.rst
   datetime_label.rst
   image.rst
   label.rst
   log.rst
   related_display_button.rst
   scale.rst
   symbol.rst
   analog_indicator.rst
   nt_table.rst

Input Widgets
-------------
.. toctree::
   :maxdepth: 1

   checkbox.rst
   datetime_edit.rst
   enum_button.rst
   enum_combo_box.rst
   line_edit.rst
   pushbutton.rst
   shell_command.rst
   slider.rst
   spinbox.rst
   waveformtable.rst

Plot Widgets
------------
.. toctree::
   :maxdepth: 1

   curve_editor.rst
   scatterplot.rst
   timeplot.rst
   event_plot.rst
   archiver_timeplot.rst
   waveformplot.rst

Container Widgets
-----------------
.. toctree::
   :maxdepth: 1

   embedded_display.rst
   frame.rst
   tab_widget.rst
   template_repeater.rst

Drawing Widgets
---------------
.. toctree::
   :maxdepth: 1

   drawing.rst

Base Widgets
------------
.. toctree::
   :maxdepth: 1

   PyDMWidget.rst

Utilities
---------
.. toctree::
   :maxdepth: 1

   utilities.rst
